@@ -53,14 +53,15 @@
 #include <panel-applet-gconf.h>
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 #include <libbonobo.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnome/libgnome.h>
 #include <gconf/gconf-client.h>
+#include <libgnomeui/gnome-help.h>
+#include <libgnome/gnome-init.h>
+#include <libgnomeui/gnome-url.h>
 
 #ifdef HAVE_LIBECAL
 #include "calendar-client.h"
-#include "cut-n-paste/eggcellrenderertext.h"
 #endif
 
 #define INTERNETSECOND (864)
@@ -634,8 +635,6 @@ handle_tasks_changed (ClockData *cd)
         g_slist_free (events);
 
         update_frame_visibility (cd->task_list, GTK_TREE_MODEL (cd->tasks_filter));
-        if (cd->calendar_popup && GTK_WIDGET_REALIZED (cd->toggle))
-                position_calendar_popup (cd, cd->calendar_popup, cd->toggle);
 }
 
 static void
@@ -681,7 +680,7 @@ handle_task_percent_complete_edited (ClockData           *cd,
         GtkTreeIter  iter;
         char        *uid;
         int          percent_complete;
-        char        *error = NULL, *text_copy;
+        char        *error = NULL;
 
         path       = gtk_tree_path_new_from_string (path_str);
         child_path = gtk_tree_model_filter_convert_path_to_child_path (cd->tasks_filter, path);
@@ -690,10 +689,7 @@ handle_task_percent_complete_edited (ClockData           *cd,
                             TASK_COLUMN_UID, &uid,
                             -1);
 
-        text_copy = g_strdup (text);
-        text_copy = g_strdelimit (text_copy, "%", ' ');
-        text_copy = g_strstrip (text_copy);
-        percent_complete = (int) g_strtod (text_copy, &error);
+        percent_complete = (int) g_strtod (text, &error);
         if (!error || !error [0]) {
                 gboolean task_completed;
 
@@ -707,7 +703,6 @@ handle_task_percent_complete_edited (ClockData           *cd,
         }
 
         g_free (uid);
-        g_free (text_copy);
         gtk_tree_path_free (path);
         gtk_tree_path_free (child_path);
 }
@@ -808,7 +803,6 @@ task_activated_cb (GtkTreeView       *view,
                    GtkTreeViewColumn *column,
                    ClockData         *cd)
 {
-        GError     *err = NULL;
         GtkTreeIter iter;
         char       *uri;
 
@@ -817,7 +811,9 @@ task_activated_cb (GtkTreeView       *view,
                             TASK_COLUMN_URL, &uri, -1);
 
         if (uri)
-                gnome_url_show (uri, &err);
+                gnome_url_show_on_screen (uri,
+					  gtk_widget_get_screen (cd->applet),
+					  NULL);
 
         return TRUE;
 }
@@ -976,8 +972,8 @@ create_task_list (ClockData  *cd,
 
         /* Summary */
         column = gtk_tree_view_column_new ();
-        cell = egg_cell_renderer_text_new ();
-        egg_cell_renderer_text_set_ellipsize (EGG_CELL_RENDERER_TEXT (cell), TRUE);
+        cell = gtk_cell_renderer_text_new ();
+        g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
         gtk_tree_view_column_pack_start (column, cell, TRUE);
         gtk_tree_view_column_set_attributes (column, cell,
                                              "text", TASK_COLUMN_SUMMARY,
@@ -1055,8 +1051,6 @@ handle_appointments_changed (ClockData *cd)
         g_slist_free (events);
 
         update_frame_visibility (cd->appointment_list, GTK_TREE_MODEL (cd->appointments_model));
-        if (cd->calendar_popup && GTK_WIDGET_REALIZED (cd->toggle))
-                position_calendar_popup (cd, cd->calendar_popup, cd->toggle);
 }
 
 static GtkWidget *
@@ -1121,8 +1115,8 @@ create_appointment_list (ClockData  *cd,
   
         /* Summary */
         column = gtk_tree_view_column_new ();
-        cell = egg_cell_renderer_text_new ();
-        egg_cell_renderer_text_set_ellipsize (EGG_CELL_RENDERER_TEXT (cell), TRUE);
+        cell = gtk_cell_renderer_text_new ();
+        g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
         gtk_tree_view_column_pack_start (column, cell, TRUE);
         gtk_tree_view_column_add_attribute (column, cell,
                                             "text", APPOINTMENT_COLUMN_SUMMARY);
@@ -1350,12 +1344,13 @@ position_calendar_popup (ClockData *cd,
 	GtkRequisition  req;
 	GdkScreen      *screen;
 	GdkRectangle    monitor;
+	GdkGravity      gravity = GDK_GRAVITY_NORTH_WEST;
 	int             button_w, button_h;
 	int             x, y;
 	int             w, h;
 	int             i, n;
 	gboolean        found_monitor = FALSE;
-		
+
 	/* Get root origin of the toggle button, and position above that. */
 	gdk_window_get_origin (button->window, &x, &y);
 
@@ -1379,7 +1374,6 @@ position_calendar_popup (ClockData *cd,
 		}
 	}
 
-
 	if ( ! found_monitor) {
 		/* eek, we should be on one of those xinerama
 		   monitors */
@@ -1399,25 +1393,44 @@ position_calendar_popup (ClockData *cd,
 		x += button_w;
 		if ((y + h) > monitor.y + monitor.height)
 			y -= (y + h) - (monitor.y + monitor.height);
+
+		if ((y + h) > (monitor.height / 2))
+			gravity = GDK_GRAVITY_SOUTH_WEST;
+		else
+			gravity = GDK_GRAVITY_NORTH_WEST;
+
 		break;
 	case PANEL_APPLET_ORIENT_LEFT:
 		x -= w;
 		if ((y + h) > monitor.y + monitor.height)
 			y -= (y + h) - (monitor.y + monitor.height);
+
+		if ((y + h) > (monitor.height / 2))
+			gravity = GDK_GRAVITY_SOUTH_EAST;
+		else
+			gravity = GDK_GRAVITY_NORTH_EAST;
+
 		break;
 	case PANEL_APPLET_ORIENT_DOWN:
 		y += button_h;
 		if ((x + w) > monitor.x + monitor.width)
 			x -= (x + w) - (monitor.x + monitor.width);
+
+		gravity = GDK_GRAVITY_NORTH_WEST;
+
 		break;
 	case PANEL_APPLET_ORIENT_UP:
 		y -= h;
 		if ((x + w) > monitor.x + monitor.width)
 			x -= (x + w) - (monitor.x + monitor.width);
+
+		gravity = GDK_GRAVITY_SOUTH_WEST;
+
 		break;
 	}
 		
 	gtk_window_move (GTK_WINDOW (window), x, y);
+	gtk_window_set_gravity (GTK_WINDOW (window), gravity);
 }
 
 static void
@@ -1590,30 +1603,30 @@ applet_change_background (PanelApplet               *applet,
 			  GdkPixmap                 *pixmap,
 			  ClockData                 *cd)
 {
-        GtkRcStyle *rc_style;
-        GtkStyle   *style;
+	GtkRcStyle *rc_style;
+	GtkStyle   *style;
 
-        /* reset style */
-        gtk_widget_set_style (GTK_WIDGET (cd->applet), NULL);
-        rc_style = gtk_rc_style_new ();
-        gtk_widget_modify_style (GTK_WIDGET (cd->applet), rc_style);
-        g_object_unref (rc_style);
+	/* reset style */
+	gtk_widget_set_style (GTK_WIDGET (cd->applet), NULL);
+	rc_style = gtk_rc_style_new ();
+	gtk_widget_modify_style (GTK_WIDGET (cd->applet), rc_style);
+	g_object_unref (rc_style);
 
-        switch (type) {
-        case PANEL_NO_BACKGROUND:
-                break;
-        case PANEL_COLOR_BACKGROUND:
-                gtk_widget_modify_bg (GTK_WIDGET (cd->applet),
-                                      GTK_STATE_NORMAL, color);
-                break;
-        case PANEL_PIXMAP_BACKGROUND:
-                style = gtk_style_copy (GTK_WIDGET (cd->applet)->style);
-                if (style->bg_pixmap[GTK_STATE_NORMAL])
-                        g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-                style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-                gtk_widget_set_style (GTK_WIDGET (cd->applet), style);
-                break;
-        }
+	switch (type) {
+	case PANEL_NO_BACKGROUND:
+		break;
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (cd->applet),
+				      GTK_STATE_NORMAL, color);
+		break;
+	case PANEL_PIXMAP_BACKGROUND:
+		style = gtk_style_copy (GTK_WIDGET (cd->applet)->style);
+		if (style->bg_pixmap[GTK_STATE_NORMAL])
+			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+		gtk_widget_set_style (GTK_WIDGET (cd->applet), style);
+		break;
+	}
 }
 
 
@@ -2075,6 +2088,7 @@ fill_clock_applet (PanelApplet *applet)
 	gtk_container_set_border_width (GTK_CONTAINER (cd->toggle), 0);
 	gtk_container_add (GTK_CONTAINER (cd->applet), cd->toggle);
 
+	gtk_window_set_default_icon_name ("clock");
 	gtk_widget_show (cd->applet);
 
 	/* FIXME: Update this comment. */
@@ -2333,7 +2347,6 @@ display_properties_dialog (BonoboUIComponent *uic,
 	GtkWidget *vbox;
 	GtkWidget *combo;
 	GtkWidget *label;
-	char      *file;
 
 	if (cd->props) {
 		gtk_window_set_screen (GTK_WINDOW (cd->props),
@@ -2357,18 +2370,6 @@ display_properties_dialog (BonoboUIComponent *uic,
 	gtk_container_set_border_width (GTK_CONTAINER (cd->props), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (cd->props)->vbox), 2);
 		
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-	                                  "gnome-clock.png", TRUE, NULL);
-	if (file) {
-		GdkPixbuf *pixbuf;
-		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-		gtk_window_set_icon (GTK_WINDOW (cd->props), pixbuf);
-		g_object_unref (pixbuf);
-		g_free (file);
-	}
-	else
-		g_warning (G_STRLOC ": gnome-clock.png cannot be found");
-
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (cd->props)->vbox), vbox, FALSE, FALSE, 0);
@@ -2516,9 +2517,6 @@ display_about_dialog (BonoboUIComponent *uic,
 		      ClockData         *cd,
 		      const gchar       *verbname)
 {
-	GdkPixbuf *pixbuf = NULL;
-	gchar *file;
-	
 	static const gchar *authors[] =
 	{
 		"George Lebl <jirka@5z.com>",
@@ -2531,7 +2529,7 @@ display_about_dialog (BonoboUIComponent *uic,
 		NULL
 	};
 	/* Translator credits */
-	const char *translator_credits = _("translator_credits");
+	const char *translator_credits = _("translator-credits");
 
 	if (cd->about) {
 		gtk_window_set_screen (GTK_WINDOW (cd->about),
@@ -2540,33 +2538,22 @@ display_about_dialog (BonoboUIComponent *uic,
 		return;
 	}
 
-	pixbuf = NULL;
-	
-	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
-	                                  "gnome-clock.png", TRUE, NULL);
-	if (file) {
-		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-		g_free (file);
-	} else
-		g_warning (G_STRLOC ": gnome-clock.png cannot be found");
-
-	cd->about = gnome_about_new (_("Clock"), VERSION,
-				 "Copyright \xc2\xa9 1998-2002 Free Software Foundation. Inc.",
-				 _("The Clock displays the current time and date"),
-				 authors,
-				 documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 pixbuf);
+	cd->about = gtk_about_dialog_new ();
+	g_object_set (cd->about,
+		      "name",  _("Clock"),
+		      "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 1998-2004 Free Software Foundation, Inc.",
+		      "comments", _("The Clock displays the current time and date"),
+		      "authors", authors,
+		      "documenters", documenters,
+		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
+		      "logo_icon_name", "clock",
+		      NULL);
 	
 	gtk_window_set_wmclass (GTK_WINDOW (cd->about), "clock", "Clock");
 	gtk_window_set_screen (GTK_WINDOW (cd->about),
 			       gtk_widget_get_screen (cd->applet));
 
-	if (pixbuf) {
-		gtk_window_set_icon (GTK_WINDOW (cd->about), pixbuf);
-		g_object_unref (pixbuf);
-	}
-	
 	g_signal_connect (G_OBJECT(cd->about), "destroy",
 			  (GCallback)gtk_widget_destroyed, &cd->about);
 	
