@@ -33,13 +33,12 @@
 
 #include <panel-applet.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-help.h>
 
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 
 #include "inlinepixbufs.h"
-#include "eel/eel-ellipsizing-label.h"
 #include "wncklet.h"
 
 typedef struct {
@@ -56,27 +55,16 @@ typedef struct {
 	GHashTable   *window_hash;
 
 	int           size;
-
-	GnomeIconTheme *icon_theme;
 } WindowMenu;
 
+typedef struct {
+	GtkWidget *item;
+	GtkWidget *label;
+} window_hash_item;
+
 static void window_menu_connect_to_window (WindowMenu *window_menu,
 					   WnckWindow *window);
 
-static void
-window_menu_make_label_bold (GtkLabel *label)
-{
-	PangoFontDescription *font_desc;
-
-	font_desc = pango_font_description_new ();
-
-	pango_font_description_set_weight (font_desc, PANGO_WEIGHT_BOLD);
-
-	gtk_widget_modify_font (GTK_WIDGET (label), font_desc);
-
-	pango_font_description_free (font_desc);
-}
-
 static void
 window_menu_help (BonoboUIComponent *uic,
 		  WindowMenu        *window_menu,
@@ -127,10 +115,7 @@ window_menu_about (BonoboUIComponent *uic,
                 "Sun GNOME Documentation Team <gdocteam@sun.com>",
                 NULL 
         };
-	const char *translator_credits = _("translator_credits");
-
-	GdkPixbuf        *pixbuf = NULL;
-	char             *file;
+	const char *translator_credits = _("translator-credits");
 
 	if (window_menu->about_dialog) {
 		gtk_window_set_screen (GTK_WINDOW (window_menu->about_dialog),
@@ -139,30 +124,26 @@ window_menu_about (BonoboUIComponent *uic,
 		return;
 	}
 
-	file = gnome_icon_theme_lookup_icon (window_menu->icon_theme,
-					     "panel-window-menu",
-					     48, NULL, NULL);
-	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
-	g_free (file);
-
-	window_menu->about_dialog = gnome_about_new (_("Window Selector"), VERSION,
-				 "Copyright \xc2\xa9 2003 Sun Microsystems, Inc.\n"
-				 "Copyright \xc2\xa9 2001 Free Software Foundation, Inc.\n"
-				 "Copyright \xc2\xa9 2000 Helix Code, Inc.",
-				 _("The Window Selector shows a list of all windows and lets you browse them."),
-				 authors,
-				 documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 pixbuf);
+	window_menu->about_dialog = gtk_about_dialog_new ();
+	g_object_set (window_menu->about_dialog,
+		      "name",  _("Workspace Selector"),
+		      "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 2003 Sun Microsystems, Inc.\n"
+				   "Copyright \xc2\xa9 2001 Free Software Foundation, Inc.\n"
+				   "Copyright \xc2\xa9 2000 Helix Code, Inc.",
+		      "comments", _("The Window Selector shows a list of all windows and lets you browse them."),
+		      "authors", authors,
+		      "documenters", documenters,
+		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
+		      "logo_icon_name", "panel-window-menu",
+		      NULL);
 
 	gtk_window_set_wmclass (GTK_WINDOW (window_menu->about_dialog), "window-menu", "WindowMenu");
 	gtk_window_set_screen (GTK_WINDOW (window_menu->about_dialog),
 			       gtk_widget_get_screen (window_menu->applet));
 
-	if (pixbuf) {
-		gtk_window_set_icon (GTK_WINDOW (window_menu->about_dialog), pixbuf);
-		g_object_unref (pixbuf);
-	}
+	gtk_window_set_icon_name (GTK_WINDOW (window_menu->about_dialog),
+				  "panel-window-menu"); 
 
 	g_signal_connect (window_menu->about_dialog, "destroy",
 			  (GCallback) gtk_widget_destroyed, &window_menu->about_dialog);
@@ -183,19 +164,12 @@ window_menu_destroy (GtkWidget  *widget,
 	if (window_menu->menu)
 		gtk_widget_destroy (window_menu->menu);
 	window_menu->menu = NULL;
+	window_menu->no_windows_item = NULL;
 
 	if (window_menu->icon_pixbuf)
 		g_object_unref (window_menu->icon_pixbuf);
 	window_menu->icon_pixbuf = NULL;
 
-	if (window_menu->icon_theme)
-		g_object_unref (window_menu->icon_theme);
-        window_menu->icon_theme = NULL;
-
-	if (window_menu->no_windows_item)
-		g_object_unref (window_menu->no_windows_item);
-	window_menu->no_windows_item = NULL;
-
 	if (window_menu->about_dialog) {
 		gtk_widget_destroy (window_menu->about_dialog);
 		window_menu->about_dialog = NULL;
@@ -322,12 +296,112 @@ window_menu_set_active_window (WindowMenu *window_menu,
 	window_menu->icon_window = window;
 }
 
+/* The results of this function will need to be freed. */
+static char *
+window_menu_get_window_name (WnckWindow *window)
+{
+	const char *const_name;
+	char *return_value;
+	char *name;
+
+	const_name = wnck_window_get_name (window);
+	if (!const_name)
+		name = g_strdup (_("Unknown Window"));
+	else
+		name = g_strdup (const_name);
+
+	if (wnck_window_demands_attention (window)) {
+		return_value = g_strdup_printf ("<b>%s</b>", name);
+		g_free (name);
+		name = return_value;
+	}
+
+	if (wnck_window_is_shaded (window)) {
+		return_value = g_strdup_printf ("=%s=", name);
+		g_free (name);
+	} else if (wnck_window_is_minimized (window)) {
+		return_value = g_strdup_printf ("[%s]", name);
+		g_free (name);
+	} else
+		return_value = name;
+
+	return return_value;
+}
+
 static void
 window_menu_window_icon_changed (WnckWindow *window,
 				 WindowMenu *window_menu)
 {
+	window_hash_item *item;
+	GtkWidget        *image;
+
 	if (window_menu->icon_window == window)
 		window_menu_set_active_window (window_menu, window);
+
+	item = NULL;
+
+	item = g_hash_table_lookup (window_menu->window_hash, window);
+	if (item != NULL) {
+		image = gtk_image_new ();
+		window_menu_set_window_icon (window_menu, image, window, TRUE);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item->item),
+					       GTK_WIDGET (image));
+		gtk_widget_show (image);
+	}
+}
+
+static void
+window_menu_window_name_changed (WnckWindow *window,
+				 WindowMenu *window_menu)
+{
+	window_hash_item *item;
+	char *window_name;
+
+	item = NULL;
+	window_name = NULL;
+
+	item = g_hash_table_lookup (window_menu->window_hash, window);
+	if (item != NULL) {
+		window_name = window_menu_get_window_name (window);
+		gtk_label_set_text (GTK_LABEL (item->label), window_name);
+		if (window_name != NULL)
+			g_free (window_name);
+	}
+}
+
+static void
+window_menu_window_state_changed (WnckWindow *window,
+				  WnckWindowState changed_mask,
+				  WnckWindowState new_state,
+				  WindowMenu *window_menu)
+{
+	window_hash_item *item;
+	char *window_name;
+
+	if (!(changed_mask & (WNCK_WINDOW_STATE_MINIMIZED|WNCK_WINDOW_STATE_SHADED|WNCK_WINDOW_STATE_SKIP_TASKLIST|WNCK_WINDOW_STATE_DEMANDS_ATTENTION)))
+			return;
+
+	item = NULL;
+	window_name = NULL;
+
+	item = g_hash_table_lookup (window_menu->window_hash, window);
+	if (item == NULL)
+		return;
+
+	if (changed_mask & WNCK_WINDOW_STATE_SKIP_TASKLIST) {
+		if (wnck_window_is_skip_tasklist (window)) {
+			gtk_widget_hide (item->item);
+		} else {
+			gtk_widget_show (item->item);
+		}
+	}
+
+	if (changed_mask & (WNCK_WINDOW_STATE_MINIMIZED|WNCK_WINDOW_STATE_SHADED|WNCK_WINDOW_STATE_DEMANDS_ATTENTION)) {
+		window_name = window_menu_get_window_name (window);
+		gtk_label_set_text (GTK_LABEL (item->label), window_name);
+		if (window_name != NULL)
+			g_free (window_name);
+	}
 }
 
 static void
@@ -395,17 +469,28 @@ get_width (GtkWidget *widget, const char *text)
 static GtkWidget*
 window_menu_item_new (WindowMenu  *window_menu,
 		      const gchar *label,
-		      gboolean make_bold)
+		      WnckWindow  *window)
 {
 	GtkWidget *item;
 	GtkWidget *ellipsizing_label;
+	window_hash_item *hash_item;
 
 	item = gtk_image_menu_item_new ();
 	
-	ellipsizing_label = eel_ellipsizing_label_new (label);
+	ellipsizing_label = gtk_label_new (label);
 	gtk_misc_set_alignment (GTK_MISC (ellipsizing_label), 0.0, 0.5);
-	if (make_bold)
-		window_menu_make_label_bold (GTK_LABEL (ellipsizing_label));
+	gtk_label_set_ellipsize (GTK_LABEL (ellipsizing_label),
+				 PANGO_ELLIPSIZE_END);
+	/* if window demands attention, we need markup */
+	if (window != NULL)
+		gtk_label_set_use_markup (GTK_LABEL (ellipsizing_label), TRUE);
+
+	if (window != NULL) {
+		hash_item = g_new0 (window_hash_item, 1);
+		hash_item->item = item;
+		hash_item->label = ellipsizing_label;
+		g_hash_table_insert (window_menu->window_hash, window, hash_item);
+	}
 
 	gtk_container_add (GTK_CONTAINER (item), ellipsizing_label);
 
@@ -423,32 +508,19 @@ window_menu_add_window (WindowMenu *window_menu,
 	WnckWorkspace *workspace; 
 	GtkWidget     *item;
 	GtkWidget     *image;
-	const char    *name;
-	char          *label;
-	char          *freeme = NULL;
+	char          *name;
 
 	if (wnck_window_is_skip_tasklist (window))
 		return;
 
-	name = wnck_window_get_name (window);
-	if (!name)
-		name = _("Unknown Window");
-
-	if (wnck_window_is_shaded (window)) {
-		label = g_strdup_printf ("=%s=", name);
-		freeme = label;
-	} else if (wnck_window_is_minimized (window)) {
-		label = g_strdup_printf ("[%s]", name);
-		freeme = label;
-	} else {
-		label = (char *) name;
-	}
+	name = window_menu_get_window_name (window);
 
 	item = window_menu_item_new (window_menu,
-				     label,
-				     wnck_window_demands_attention (window));
-	if (freeme)
-		g_free (freeme);
+				     name,
+				     window);
+
+	if (name != NULL)
+		g_free (name);
 
 	image = gtk_image_new ();
 
@@ -466,7 +538,7 @@ window_menu_add_window (WindowMenu *window_menu,
 	else
 		gtk_menu_shell_append (GTK_MENU_SHELL (window_menu->menu), item);
 
-	g_hash_table_insert (window_menu->window_hash, window, item);
+
 	g_signal_connect_swapped (item, "activate",
 				  G_CALLBACK (window_menu_activate_window),
 				  window);
@@ -495,7 +567,7 @@ window_menu_window_closed (WnckScreen *screen,
 			   WnckWindow *window,
 			   WindowMenu *window_menu)
 {
-	GtkWidget *item;
+	window_hash_item *item;
 
 	if (window == window_menu->icon_window)
 		window_menu_set_active_window (window_menu, NULL);
@@ -507,7 +579,7 @@ window_menu_window_closed (WnckScreen *screen,
 	if (!item)
 		return;
 
-	gtk_widget_hide (item);
+	gtk_widget_hide (item->item);
 	gtk_menu_reposition (GTK_MENU (window_menu->menu));
 }
 
@@ -519,6 +591,14 @@ window_menu_connect_to_window (WindowMenu *window_menu,
 				     G_CALLBACK (window_menu_window_icon_changed),
 				     window_menu,
 				     window_menu->applet);
+	wncklet_connect_while_alive (window, "name_changed",
+				     G_CALLBACK (window_menu_window_name_changed),
+				     window_menu,
+				     window_menu->applet);
+	wncklet_connect_while_alive (window, "state_changed",
+				     G_CALLBACK (window_menu_window_state_changed),
+				     window_menu,
+				     window_menu->applet);
 }
 
 static void
@@ -550,13 +630,14 @@ window_menu_destroy_menu (GtkWidget  *widget,
 	if (window_menu->window_hash)
 		g_hash_table_destroy (window_menu->window_hash);
 	window_menu->window_hash = NULL;
+	window_menu->no_windows_item = NULL;
 }
 
 static void
 window_menu_menu_hidden (GtkWidget  *menu,
 			 WindowMenu *window_menu)
 {
-	gtk_frame_set_shadow_type (GTK_FRAME (window_menu->frame), GTK_SHADOW_NONE);
+	gtk_widget_set_state (GTK_WIDGET (window_menu->applet), GTK_STATE_NORMAL);
 }
 
 static void
@@ -603,19 +684,16 @@ window_menu_popup_menu (WindowMenu *window_menu,
 		window_menu->menu = gtk_menu_new (); 
 		g_signal_connect (window_menu->menu, "hide",
 				  G_CALLBACK (window_menu_menu_hidden), window_menu);
+		g_signal_connect (window_menu->menu, "destroy",
+				  G_CALLBACK (window_menu_destroy_menu), window_menu);
 	}
 
 	list = gtk_container_get_children (GTK_CONTAINER (window_menu->menu));
 	for (l = list; l; l = l->next)
 		gtk_container_remove (GTK_CONTAINER (window_menu->menu), l->data);
 	g_list_free (list);
-
-	if (window_menu->no_windows_item)
-		g_object_unref (window_menu->no_windows_item);
 	window_menu->no_windows_item = NULL;
 
-	g_signal_connect (window_menu->menu, "destroy",
-			  G_CALLBACK (window_menu_destroy_menu), window_menu);
 
 	seperator = gtk_separator_menu_item_new ();
 	gtk_widget_show (seperator);
@@ -626,7 +704,10 @@ window_menu_popup_menu (WindowMenu *window_menu,
 
 	if (window_menu->window_hash)
 		g_hash_table_destroy (window_menu->window_hash);
-	window_menu->window_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
+	window_menu->window_hash = g_hash_table_new_full (g_direct_hash,
+							  g_direct_equal,
+							  NULL,
+							  g_free);
 
 	for (l = windows; l; l = l->next)
 		window_menu_add_window (window_menu, l->data);
@@ -641,7 +722,7 @@ window_menu_popup_menu (WindowMenu *window_menu,
 		window_menu->no_windows_item =
 			window_menu_item_new (window_menu,
 					      _("No Windows Open"),
-					      FALSE);
+					      NULL);
 
 		gtk_widget_set_sensitive (window_menu->no_windows_item, FALSE);
 		gtk_widget_show (window_menu->no_windows_item);	
@@ -654,11 +735,11 @@ window_menu_popup_menu (WindowMenu *window_menu,
 	gtk_menu_set_screen (GTK_MENU (window_menu->menu),
 			     gtk_widget_get_screen (window_menu->applet));
 
-	gtk_frame_set_shadow_type (GTK_FRAME (window_menu->frame), GTK_SHADOW_IN);
+	gtk_widget_set_state (GTK_WIDGET (window_menu->applet), GTK_STATE_SELECTED);
 
 	gtk_menu_popup (GTK_MENU (window_menu->menu),
 			NULL, NULL,
-			window_menu_position_menu, window_menu->frame,
+			window_menu_position_menu, window_menu->applet,
 			button, activate_time);
 }
 
@@ -696,6 +777,39 @@ window_menu_key_press_event (GtkWidget   *widget,
 	return FALSE;
 }
 
+static void
+window_menu_change_background (PanelApplet               *applet,
+			       PanelAppletBackgroundType  type,
+			       GdkColor                  *color,
+			       GdkPixmap                 *pixmap,
+			       WindowMenu                *window_menu)
+{
+	GtkRcStyle *rc_style;
+	GtkStyle   *style;
+
+	/* reset style */
+	gtk_widget_set_style (GTK_WIDGET (window_menu->applet), NULL);
+	rc_style = gtk_rc_style_new ();
+	gtk_widget_modify_style (GTK_WIDGET (window_menu->applet), rc_style);
+	g_object_unref (rc_style);
+
+	switch (type) {
+	case PANEL_NO_BACKGROUND:
+		break;
+	case PANEL_COLOR_BACKGROUND:
+		gtk_widget_modify_bg (GTK_WIDGET (window_menu->applet),
+				      GTK_STATE_NORMAL, color);
+		break;
+	case PANEL_PIXMAP_BACKGROUND:
+		style = gtk_style_copy (GTK_WIDGET (window_menu->applet)->style);
+		if (style->bg_pixmap[GTK_STATE_NORMAL])
+			g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+		style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+		gtk_widget_set_style (GTK_WIDGET (window_menu->applet), style);
+		break;
+	}
+}
+
 static void
 window_menu_setup_menu (WindowMenu *window_menu)
 {
@@ -735,6 +849,27 @@ set_tooltip (GtkWidget  *widget,
 	gtk_tooltips_set_tip (tooltips, widget, tip, NULL);
 }
 
+static inline void
+force_no_focus_padding (GtkWidget *widget)
+{
+        gboolean first_time = TRUE;
+
+        if (first_time) {
+                gtk_rc_parse_string ("\n"
+                                     "   style \"window-menu-applet-button-style\"\n"
+                                     "   {\n"
+                                     "      GtkWidget::focus-line-width=0\n"
+                                     "      GtkWidget::focus-padding=0\n"
+                                     "   }\n"
+                                     "\n"
+                                     "    widget \"*.window-menu-applet-button\" style \"window-menu-applet-button-style\"\n"
+                                     "\n");
+                first_time = FALSE;
+        }
+
+        gtk_widget_set_name (widget, "window-menu-applet-button");
+}
+
 gboolean
 window_menu_applet_fill (PanelApplet *applet)
 {
@@ -745,6 +880,8 @@ window_menu_applet_fill (PanelApplet *applet)
 	window_menu = g_new0 (WindowMenu, 1);
 
 	window_menu->applet = GTK_WIDGET (applet);
+	force_no_focus_padding (window_menu->applet);
+
 	atk_obj = gtk_widget_get_accessible (window_menu->applet);
 	atk_object_set_name (atk_obj, _("Window Selector"));
 	atk_object_set_description (atk_obj, _("Tool to switch between windows"));
@@ -752,8 +889,6 @@ window_menu_applet_fill (PanelApplet *applet)
  
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 
-        window_menu->icon_theme = gnome_icon_theme_new ();
-
 	g_signal_connect (window_menu->applet, "destroy",
 			  G_CALLBACK (window_menu_destroy), window_menu);
 
@@ -761,14 +896,9 @@ window_menu_applet_fill (PanelApplet *applet)
 		applet, NULL, "GNOME_WindowMenuApplet.xml",
 		NULL, window_menu_verbs, window_menu);
 
-	window_menu->frame = gtk_frame_new (NULL);
-	gtk_container_set_border_width (GTK_CONTAINER (window_menu->frame), 0);
-	gtk_frame_set_shadow_type (GTK_FRAME (window_menu->frame), GTK_SHADOW_NONE);
-	gtk_widget_show (window_menu->frame);
-
 	alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
 	gtk_widget_show (alignment);
-	gtk_container_add (GTK_CONTAINER (window_menu->frame), alignment);
+	gtk_container_add (GTK_CONTAINER (window_menu->applet), alignment);
 
 	window_menu->image = gtk_image_new ();
 	gtk_widget_show (window_menu->image);
@@ -780,14 +910,14 @@ window_menu_applet_fill (PanelApplet *applet)
 	g_signal_connect (window_menu->image, "size_allocate",
 			  G_CALLBACK (window_menu_size_allocate), window_menu);
  
-	gtk_container_add (GTK_CONTAINER (window_menu->applet), window_menu->frame); 
-
 	window_menu_setup_menu (window_menu);
 
 	g_signal_connect (window_menu->applet, "button_press_event",
 			  G_CALLBACK (window_menu_button_press_event), window_menu);
 	g_signal_connect (window_menu->applet, "key_press_event",
 			  G_CALLBACK (window_menu_key_press_event), window_menu);
+	g_signal_connect (G_OBJECT (window_menu->applet), "change_background",
+			  G_CALLBACK (window_menu_change_background), window_menu);
 
     	gtk_widget_show (GTK_WIDGET (window_menu->applet));
 
