@@ -12,8 +12,8 @@
 #include <signal.h>
 #include <sys/wait.h>
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-icon-theme.h>
+#include <libgnomeui/gnome-ui-init.h>
 
 #include <libbonoboui.h>
 #include <bonobo-activation/bonobo-activation.h>
@@ -31,6 +31,7 @@
 #include "xstuff.h"
 #include "panel-stock-icons.h"
 #include "panel-action-protocol.h"
+#include "panel-lockdown.h"
 
 #include "nothing.cP"
 
@@ -42,15 +43,10 @@ GtkTooltips *panel_tooltips = NULL;
 
 GnomeIconTheme *panel_icon_theme = NULL;
 
-/* FIXME: old lockdown globals */
-gboolean commie_mode = FALSE;
-gboolean no_run_box = FALSE;
-
 static char *profile_arg;
 
 static const struct poptOption options[] = {
   {"profile", '\0', POPT_ARG_STRING, &profile_arg, 0, N_("Specify a profile name to load"), NULL},
-  POPT_AUTOHELP
   {NULL, '\0', 0, NULL, 0}
 };
 
@@ -74,7 +70,7 @@ main (int argc, char **argv)
 	panel_icon_theme = gnome_icon_theme_new ();
 	gnome_icon_theme_set_allow_svg (panel_icon_theme, TRUE);
 	
-	panel_register_window_icon ();
+	gtk_window_set_default_icon_name ("gnome-panel");
 
 	panel_tooltips = gtk_tooltips_new ();
 
@@ -84,14 +80,17 @@ main (int argc, char **argv)
 
         init_menus ();
 
-	panel_gconf_add_dir ("/desktop/gnome/interface");
+	gconf_client_add_dir (panel_gconf_get_client (),
+			      "/desktop/gnome/interface",
+			      GCONF_CLIENT_PRELOAD_NONE,
+			      NULL);
 
 	panel_global_config_load ();
+	panel_lockdown_init ();
 	panel_profile_load (profile_arg);
 
 	panel_session_init (argv [0]);
 
-
 	/*add forbidden lists to ALL panels*/
 	g_slist_foreach (panels,
 			 (GFunc)panel_widget_add_forbidden,
@@ -99,5 +98,7 @@ main (int argc, char **argv)
 
 	gtk_main ();
 
+	panel_lockdown_finalize ();
+
 	return 0;
 }
