@@ -23,10 +23,8 @@
 #include <math.h>
 
 #include <gdk/gdkkeysyms.h>
-#include <libgnome/libgnome.h>
+#include <gtk/gtkenums.h>
 #include <libgnome/gnome-desktop-item.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnomeui/gnome-ditem-edit.h>
 #include <gconf/gconf-client.h>
 #include <libbonobo.h>
 
@@ -38,7 +36,6 @@
 #include "menu.h"
 
 #include "button-widget.h"
-#include "distribution.h"
 #include "launcher.h"
 #include "nothing.h"
 #include "menu-fentry.h"
@@ -111,9 +108,6 @@ static GtkWidget * create_menu_at_fr (GtkWidget *menu,
 
 static GtkWidget * create_desktop_menu (GtkWidget *m);
 
-static void add_distribution_submenu (GtkWidget *root_menu,
-				      gboolean fake_submenus);
-
 static gboolean panel_menu_key_press_handler (GtkWidget   *widget,
 					      GdkEventKey *event);
 static PanelWidget *menu_get_panel     (GtkWidget *menu);
@@ -134,16 +128,10 @@ panel_menu_have_icons (void)
 void
 init_menus (void)
 {
-	const DistributionInfo *distribution_info = get_distribution_info ();
-
 	/*just load the menus from disk, don't make the widgets
 	  this just reads the .desktops of the top most directory
 	  and a level down*/
 	fr_read_dir (NULL, "applications:/", 0, 2);
-
-	if (distribution_info != NULL &&
-	    distribution_info->menu_init_func != NULL)
-		distribution_info->menu_init_func ();
 }
 
 static gboolean
@@ -198,7 +186,7 @@ show_about_dialog (GtkWidget *menuitem)
 		NULL
 	  };
 	/* Translator credits */
-	char *translator_credits = _("translator_credits");
+	char *translator_credits = _("translator-credits");
 	int   i;
 
 	if (about) {
@@ -211,15 +199,18 @@ show_about_dialog (GtkWidget *menuitem)
 	for (i = 0; authors [i]; i++)
 		authors [i] = _(authors [i]);
 
-	about = gnome_about_new (_("The GNOME Panel"),
-				 VERSION,
-				 "Copyright \xc2\xa9 1997-2003 Free Software Foundation, Inc.",
-				 _("This program is responsible for launching other "
-				   "applications and embedding small applets within itself."),
-				 (const char **) authors,
-				 (const char **) documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 NULL);
+	about = gtk_about_dialog_new ();
+	g_object_set (about,
+		      "name",  _("The GNOME Panel"),
+		      "version", VERSION,
+		      "copyright", "Copyright \xc2\xa9 1997-2003 Free Software Foundation, Inc.",
+		      "comments", _("This program is responsible for launching other "
+				    "applications and embedding small applets within itself."),
+		      "authors", authors,
+		      "documenters", documenters,
+		      "translator_credits", strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
+		      "logo_icon_name", "gnome-panel",
+		      NULL);
 
 	gtk_window_set_wmclass (GTK_WINDOW (about), "about_dialog", "Panel");
 	gtk_window_set_screen (GTK_WINDOW (about),
@@ -2171,27 +2162,6 @@ create_system_menu (GtkWidget *menu,
 	return menu;
 }
 
-static GtkWidget *
-create_distribution_menu (GtkWidget *menu,
-			  gboolean fake_submenus,
-			  gboolean fake)
-{
-	const DistributionInfo *info = get_distribution_info ();
-
-	if (!info)
-		return NULL;
-
-	if (!fake || menu)
-		menu = create_menu_at (menu, info->menu_path,
-				       info->menu_name,
-				       fake_submenus, FALSE);
-	else
-		menu = create_fake_menu_at (info->menu_path,
-					    info->menu_name);
-
-	return menu;
-}
-
 static void
 remove_panel (GtkWidget *menuitem,
               gpointer data)
@@ -2371,7 +2341,7 @@ create_panel_context_menu (PanelWidget *panel)
 	setup_menuitem (menuitem,
 			GTK_ICON_SIZE_MENU,
 			gtk_image_new_from_stock (
-				GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
+				GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
 				_("A_bout Panels"),
 				FALSE);
 	gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
@@ -2385,7 +2355,7 @@ create_panel_context_menu (PanelWidget *panel)
 		setup_menuitem (menuitem,
 				GTK_ICON_SIZE_MENU,
 				gtk_image_new_from_stock (
-					GNOME_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
+					GTK_STOCK_ABOUT, GTK_ICON_SIZE_MENU),
 					_("About _GNOME"),
 					FALSE);
 		gtk_menu_shell_append (GTK_MENU_SHELL (retval), menuitem);
@@ -2461,40 +2431,6 @@ create_desktop_menu (GtkWidget *menu)
 	return menu;
 }
 
-static void
-add_distribution_submenu (GtkWidget *root_menu,
-			  gboolean fake_submenus)
-{
-	GtkWidget *menu;
-	GtkWidget *menuitem;
-	const DistributionInfo *distribution_info = get_distribution_info ();
-
-	if (distribution_info == NULL)
-		return;
-
-	menu = create_distribution_menu (NULL /* menu */,
-					 fake_submenus,
-					 TRUE /* fake */);
-
-	menuitem = gtk_image_menu_item_new ();
-	setup_stock_menu_item (menuitem,
-			       panel_menu_icon_get_size (),
-			       distribution_info->stock_icon,
-			       _(distribution_info->menu_name),
-			       TRUE);
-
-	gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
-				   menu);
-	if (distribution_info->menu_show_func)
-		g_signal_connect (G_OBJECT(menu),"show",
-				   G_CALLBACK(distribution_info->menu_show_func),
-				   menuitem);
-	g_signal_connect (G_OBJECT(menu),"show",
-			  G_CALLBACK(submenu_to_display),
-			  NULL);
-}
-
 GtkWidget *
 create_root_menu (GtkWidget   *root_menu,
 		  PanelWidget *panel,
@@ -2502,27 +2438,17 @@ create_root_menu (GtkWidget   *root_menu,
 		  int          flags,
 		  gboolean     extra_items)
 {
-	const DistributionInfo *distribution_info;
 	GtkWidget              *menu;
 	GtkWidget              *menuitem;
 	gboolean                has_inline;
 	gboolean                has_subs;
-	gboolean                has_subs2;
-
-	if ((flags & MAIN_MENU_DISTRIBUTION_SUB) && !got_distro_menus ())
-		flags &= ~MAIN_MENU_DISTRIBUTION_SUB;
+	gboolean                has_inline2;
 
 	has_inline = (flags & MAIN_MENU_SYSTEM);
 
 	has_subs = (flags & MAIN_MENU_SYSTEM_SUB);
 
-	has_subs2 = (flags & (MAIN_MENU_DESKTOP_SUB |
-			      MAIN_MENU_PANEL_SUB));
-
-	if ((distribution_info = get_distribution_info ())) {
-		has_inline |= (flags & (MAIN_MENU_DISTRIBUTION));
-		has_subs |= (flags & (MAIN_MENU_DISTRIBUTION_SUB));
-	}
+	has_inline2 = (flags & MAIN_MENU_DESKTOP);
 
 	if (!root_menu)
 		root_menu = menu_new ();
@@ -2533,14 +2459,6 @@ create_root_menu (GtkWidget   *root_menu,
 		create_system_menu(root_menu, fake_submenus,
 				   FALSE /* fake */);
 
-	if (flags & MAIN_MENU_DISTRIBUTION &&
-	    distribution_info != NULL) {
-		if (distribution_info->menu_show_func)
-			distribution_info->menu_show_func(NULL,NULL);
-
-		create_distribution_menu(root_menu, fake_submenus, FALSE);
-	}
-
 	/*others here*/
 
 	if (has_subs && has_inline)
@@ -2563,10 +2481,6 @@ create_root_menu (GtkWidget   *root_menu,
 		}
 	}
 
-	if (flags & MAIN_MENU_DISTRIBUTION_SUB) {
-		add_distribution_submenu (root_menu, fake_submenus);
-	}
-
 	if (!panel_lockdown_get_disable_command_line () && extra_items) {
 		add_menu_separator (root_menu);
 		menuitem = gtk_image_menu_item_new ();
@@ -2608,7 +2522,7 @@ create_root_menu (GtkWidget   *root_menu,
 	}
 
 	if (extra_items &&
-	    panel_is_program_in_path ("gnome-panel-screenshot")) {
+	    panel_is_program_in_path ("gnome-screenshot")) {
 		menuitem = gtk_image_menu_item_new ();
 		setup_stock_menu_item (
 			menuitem, panel_menu_icon_get_size (),
@@ -2625,19 +2539,9 @@ create_root_menu (GtkWidget   *root_menu,
 					    panel_action_get_drag_id (PANEL_ACTION_SCREENSHOT));
 	}
 
-	if (((has_inline && !has_subs) || has_subs) && has_subs2)
+	if (((has_inline && !has_subs) || has_subs) && has_inline2)
 		add_menu_separator (root_menu);
 	
-	if (flags & MAIN_MENU_DESKTOP_SUB) {
-		menu = create_desktop_menu (NULL);
-		menuitem = gtk_image_menu_item_new ();
-		setup_stock_menu_item (
-			menuitem, panel_menu_icon_get_size (),
-			PANEL_STOCK_DESKTOP, _("Desktop"), TRUE);
-		gtk_menu_shell_append (GTK_MENU_SHELL (root_menu), menuitem);
-		gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), menu);
-	}
-
 	if (flags & MAIN_MENU_DESKTOP)
 		create_desktop_menu (root_menu);
 
