@@ -29,7 +29,7 @@
 
 #include "panel-action-button.h"
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "applet.h"
 #include "menu.h"
@@ -179,7 +179,7 @@ panel_action_logout (GtkWidget *widget)
 void
 panel_action_run_program (GtkWidget *widget)
 {
-	panel_run_dialog_present (gtk_widget_get_screen (widget));
+	panel_run_dialog_present (gtk_widget_get_screen (widget), gtk_get_current_event_time ());
 }
 
 /* Search For Files
@@ -213,7 +213,7 @@ panel_action_screenshot (GtkWidget *widget)
 {
 	GdkScreen *screen;
 	GError    *error = NULL;
-	char      *argv [2] = {"gnome-panel-screenshot", NULL};
+	char      *argv [2] = {"gnome-screenshot", NULL};
 
 	screen = gtk_widget_get_screen (widget);
 
@@ -221,10 +221,10 @@ panel_action_screenshot (GtkWidget *widget)
 				  G_SPAWN_SEARCH_PATH,
 				  NULL, NULL, NULL, &error)) {
 		panel_error_dialog (screen,
-				    "cannot_exec_gnome-panel-screenshot",
+				    "cannot_exec_gnome-screenshot",
 				    _("Cannot execute '%s'"),
 				    "%s",
-				    "gnome-panel-screenshot",
+				    "gnome-screenshot",
 				    error->message);
 		g_error_free (error);
 	}
