@@ -29,7 +29,6 @@
 #include <gdk/gdk.h>
 #include <gdk/gdkx.h>
 #include <X11/Xlib.h>
-#include <libgnome/gnome-i18n.h>
 
 #include "menu.h"
 #include "applet.h"
@@ -69,7 +68,7 @@ panel_action_protocol_main_menu (GdkScreen *screen,
 	panel_widget = panels->data;
 	menu = create_panel_root_menu (panel_widget);
 
-	panel_toplevel_block_auto_hide (panel_widget->toplevel);
+	panel_toplevel_push_autohide_disabler (panel_widget->toplevel);
 
 	gtk_menu_set_screen (GTK_MENU (menu), screen);
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
@@ -77,9 +76,10 @@ panel_action_protocol_main_menu (GdkScreen *screen,
 }
 
 static void
-panel_action_protocol_run_dialog (GdkScreen *screen)
+panel_action_protocol_run_dialog (GdkScreen *screen,
+				  guint32    activate_time)
 {
-	panel_run_dialog_present (screen);
+	panel_run_dialog_present (screen, activate_time);
 }
 
 static GdkFilterReturn
@@ -106,7 +106,7 @@ panel_action_protocol_filter (GdkXEvent *gdk_xevent,
 	if (xevent->xclient.data.l [0] == atom_gnome_panel_action_main_menu)
 		panel_action_protocol_main_menu (screen, xevent->xclient.data.l [1]);
 	else if (xevent->xclient.data.l [0] == atom_gnome_panel_action_run_dialog)
-		panel_action_protocol_run_dialog (screen);
+		panel_action_protocol_run_dialog (screen, xevent->xclient.data.l [1]);
 	else
 		return GDK_FILTER_CONTINUE;
 
