@@ -24,8 +24,9 @@
 #include <unistd.h>
 #include <sys/wait.h>
 
-#include <libgnomeui/libgnomeui.h>
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
+#include <libgnome/gnome-util.h>
+#include <libgnomeui/gnome-help.h>
 
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
@@ -226,7 +227,6 @@ panel_dialog (GdkScreen  *screen,
 
 	gtk_window_set_wmclass (GTK_WINDOW (dialog), class, "Panel");
 	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	gtk_widget_show_all (dialog);
 
@@ -471,28 +471,6 @@ panel_is_program_in_path (const char *program)
 	}
 }
 
-char *
-panel_pixmap_discovery (const char *name, gboolean fallback)
-{
-	char *pixmap;
-	pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-					    name,
-					    TRUE /* only_if_exists */,
-					    NULL /* ret_locations */);
-	if (pixmap == NULL)
-		pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, 
-						    name,
-						    TRUE /* only_if_exists */,
-						    NULL /* ret_locations */);
-	/* just as a fallback return something */
-	if (pixmap == NULL && fallback)
-		pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
-						    name,
-						    FALSE /* only_if_exists */,
-						    NULL /* ret_locations */);
-	return pixmap;
-}
-
 static gboolean
 panel_ensure_dir (const char *dirname)
 {
