@@ -17,21 +17,18 @@
 
 #include <gdk/gdkkeysyms.h>
 
-#include <libgnome/libgnome.h>
 #include <libbonobo.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
-#include <libgnomeui/gnome-window-icon.h>
 
 #include "panel.h"
 
 #include "applet.h"
 #include "drawer.h"
 #include "button-widget.h"
-#include "distribution.h"
 #include "launcher.h"
 #include "menu-fentry.h"
 #include "menu-util.h"
@@ -1148,19 +1145,6 @@ panel_setup (PanelToplevel *toplevel)
 	return pd;
 }
 
-void
-panel_register_window_icon (void)
-{
-	char *panel_icon;
-
-	panel_icon = panel_pixmap_discovery ("gnome-panel.png", FALSE);
-
-	if (panel_icon) {
-		gnome_window_icon_set_default_from_file (panel_icon);
-		g_free (panel_icon);
-	}
-}
-
 GdkScreen *
 panel_screen_from_panel_widget (PanelWidget *panel)
 {
@@ -1235,22 +1219,32 @@ panel_deletion_dialog (PanelToplevel *toplevel)
 {
 
 	GtkWidget *dialog;
+	char *text;
+	char *title;
+
+	if (panel_toplevel_get_is_attached (toplevel)) {
+		text = _("When a drawer is deleted, the drawer and its\n"
+			 "settings are lost. Delete this drawer?");
+		title = _("Delete Drawer");
+	} else {
+		text = _("When a panel is deleted, the panel and its\n"
+			 "settings are lost. Delete this panel?");
+		title = _("Delete Panel");
+	}
 
 	dialog = gtk_message_dialog_new (
 			GTK_WINDOW (toplevel),
 			GTK_DIALOG_MODAL,
 			GTK_MESSAGE_QUESTION,
 			GTK_BUTTONS_NONE,
-			_("When a panel is deleted, the panel "
-			"and its\n settings are lost. "
-			"Delete this panel?"));
+			text);
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_DELETE, GTK_RESPONSE_OK,
 				NULL);
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Delete Panel"));
+	gtk_window_set_title (GTK_WINDOW (dialog), title);
 
 	gtk_window_set_wmclass (GTK_WINDOW (dialog),
 				"panel_remove_query", "Panel");
